@@ -3,3 +3,7 @@ from .._impl import (
     connect_download_Platform as Platform,
 )
 
+__all__ = [
+    'Platform',
+]
+
