@@ -45,6 +45,8 @@ from .._impl import (
     event_SearchQueryVisitor as SearchQueryVisitor,
     event_SortField as SortField,
     event_SortOptions as SortOptions,
+    event_StreamingCheckOriginMetadata as StreamingCheckOriginMetadata,
+    event_StreamingChecklistEventOrigin as StreamingChecklistEventOrigin,
     event_TemplateEventOrigin as TemplateEventOrigin,
     event_TimeSeriesChannelAssociation as TimeSeriesChannelAssociation,
     event_UpdateDispositionRequest as UpdateDispositionRequest,
@@ -100,6 +102,8 @@ __all__ = [
     'SearchQueryVisitor',
     'SortField',
     'SortOptions',
+    'StreamingCheckOriginMetadata',
+    'StreamingChecklistEventOrigin',
     'TemplateEventOrigin',
     'TimeSeriesChannelAssociation',
     'UpdateDispositionRequest',
