@@ -25,6 +25,8 @@ from .._impl import (
     scout_chartdefinition_api_ColorStyle as ColorStyle,
     scout_chartdefinition_api_ColorStyleVisitor as ColorStyleVisitor,
     scout_chartdefinition_api_DataSourceRefName as DataSourceRefName,
+    scout_chartdefinition_api_DecimalPlaces as DecimalPlaces,
+    scout_chartdefinition_api_DecimalPlacesVisitor as DecimalPlacesVisitor,
     scout_chartdefinition_api_DefaultFill as DefaultFill,
     scout_chartdefinition_api_DisconnectedValueVisualization as DisconnectedValueVisualization,
     scout_chartdefinition_api_DisconnectedValueVisualizationVisitor as DisconnectedValueVisualizationVisitor,
@@ -42,6 +44,7 @@ from .._impl import (
     scout_chartdefinition_api_EnumValueVisualisationVisitor as EnumValueVisualisationVisitor,
     scout_chartdefinition_api_Event as Event,
     scout_chartdefinition_api_Figure as Figure,
+    scout_chartdefinition_api_FixedDecimalPlaces as FixedDecimalPlaces,
     scout_chartdefinition_api_FrequencyChartDefinition as FrequencyChartDefinition,
     scout_chartdefinition_api_FrequencyChartDefinitionV1 as FrequencyChartDefinitionV1,
     scout_chartdefinition_api_FrequencyChartDefinitionV2 as FrequencyChartDefinitionV2,
@@ -108,6 +111,8 @@ from .._impl import (
     scout_chartdefinition_api_LogPanelDefinitionV1 as LogPanelDefinitionV1,
     scout_chartdefinition_api_LogPanelDefinitionVisitor as LogPanelDefinitionVisitor,
     scout_chartdefinition_api_LogTagFilter as LogTagFilter,
+    scout_chartdefinition_api_MagnitudeAndPhaseDisplayMode as MagnitudeAndPhaseDisplayMode,
+    scout_chartdefinition_api_MaxDecimalPlaces as MaxDecimalPlaces,
     scout_chartdefinition_api_NeverConnectDisconnectedValues as NeverConnectDisconnectedValues,
     scout_chartdefinition_api_NumberFormat as NumberFormat,
     scout_chartdefinition_api_NumberFormatDisplayOption as NumberFormatDisplayOption,
@@ -235,6 +240,8 @@ __all__ = [
     'ColorStyle',
     'ColorStyleVisitor',
     'DataSourceRefName',
+    'DecimalPlaces',
+    'DecimalPlacesVisitor',
     'DefaultFill',
     'DisconnectedValueVisualization',
     'DisconnectedValueVisualizationVisitor',
@@ -252,6 +259,7 @@ __all__ = [
     'EnumValueVisualisationVisitor',
     'Event',
     'Figure',
+    'FixedDecimalPlaces',
     'FrequencyChartDefinition',
     'FrequencyChartDefinitionVisitor',
     'FrequencyChartDefinitionV1',
@@ -318,6 +326,8 @@ __all__ = [
     'LogPanelDefinitionVisitor',
     'LogPanelDefinitionV1',
     'LogTagFilter',
+    'MagnitudeAndPhaseDisplayMode',
+    'MaxDecimalPlaces',
     'NeverConnectDisconnectedValues',
     'NumberFormat',
     'NumberFormatDisplayOption',
