@@ -217,6 +217,7 @@ from .._impl import (
     scout_compute_api_LogarithmicCurve as LogarithmicCurve,
     scout_compute_api_LogarithmicResultDetails as LogarithmicResultDetails,
     scout_compute_api_LowPassConfiguration as LowPassConfiguration,
+    scout_compute_api_MagnitudeScaling as MagnitudeScaling,
     scout_compute_api_MaxSeries as MaxSeries,
     scout_compute_api_Maximum as Maximum,
     scout_compute_api_MeanSeries as MeanSeries,
@@ -261,6 +262,8 @@ from .._impl import (
     scout_compute_api_OffsetSeries as OffsetSeries,
     scout_compute_api_OnChangeRanges as OnChangeRanges,
     scout_compute_api_OutputFormat as OutputFormat,
+    scout_compute_api_OutputFrequencyType as OutputFrequencyType,
+    scout_compute_api_OutputPhaseUnit as OutputPhaseUnit,
     scout_compute_api_OutputRangeStart as OutputRangeStart,
     scout_compute_api_OutputRangeStartVisitor as OutputRangeStartVisitor,
     scout_compute_api_PaddedRanges as PaddedRanges,
@@ -618,6 +621,7 @@ __all__ = [
     'LogarithmicCurve',
     'LogarithmicResultDetails',
     'LowPassConfiguration',
+    'MagnitudeScaling',
     'MaxSeries',
     'Maximum',
     'MeanSeries',
@@ -662,6 +666,8 @@ __all__ = [
     'OffsetSeries',
     'OnChangeRanges',
     'OutputFormat',
+    'OutputFrequencyType',
+    'OutputPhaseUnit',
     'OutputRangeStart',
     'OutputRangeStartVisitor',
     'PaddedRanges',
