@@ -4,6 +4,8 @@ from .._impl import (
     scout_notebook_api_ChartWithOverlays as ChartWithOverlays,
     scout_notebook_api_CreateNotebookRequest as CreateNotebookRequest,
     scout_notebook_api_GetAllLabelsAndPropertiesResponse as GetAllLabelsAndPropertiesResponse,
+    scout_notebook_api_GetSnapshotHistoryRequest as GetSnapshotHistoryRequest,
+    scout_notebook_api_GetSnapshotHistoryResponse as GetSnapshotHistoryResponse,
     scout_notebook_api_Lock as Lock,
     scout_notebook_api_Notebook as Notebook,
     scout_notebook_api_NotebookDataScope as NotebookDataScope,
@@ -17,6 +19,7 @@ from .._impl import (
     scout_notebook_api_SearchNotebooksQueryVisitor as SearchNotebooksQueryVisitor,
     scout_notebook_api_SearchNotebooksRequest as SearchNotebooksRequest,
     scout_notebook_api_SearchNotebooksResponse as SearchNotebooksResponse,
+    scout_notebook_api_SnapshotSummary as SnapshotSummary,
     scout_notebook_api_SortBy as SortBy,
     scout_notebook_api_SortByField as SortByField,
     scout_notebook_api_UpdateNotebookMetadataRequest as UpdateNotebookMetadataRequest,
@@ -29,6 +32,8 @@ __all__ = [
     'ChartWithOverlays',
     'CreateNotebookRequest',
     'GetAllLabelsAndPropertiesResponse',
+    'GetSnapshotHistoryRequest',
+    'GetSnapshotHistoryResponse',
     'Lock',
     'Notebook',
     'NotebookDataScope',
@@ -42,6 +47,7 @@ __all__ = [
     'SearchNotebooksQueryVisitor',
     'SearchNotebooksRequest',
     'SearchNotebooksResponse',
+    'SnapshotSummary',
     'SortBy',
     'SortByField',
     'UpdateNotebookMetadataRequest',
