@@ -11,6 +11,7 @@ from .._impl import (
     scout_savedviews_api_ColumnPinningState as ColumnPinningState,
     scout_savedviews_api_CreateSavedViewRequest as CreateSavedViewRequest,
     scout_savedviews_api_CreateSavedViewResponse as CreateSavedViewResponse,
+    scout_savedviews_api_CustomTimeRange as CustomTimeRange,
     scout_savedviews_api_DisplayState as DisplayState,
     scout_savedviews_api_DisplayStateVisitor as DisplayStateVisitor,
     scout_savedviews_api_GetSavedViewResponse as GetSavedViewResponse,
@@ -62,6 +63,7 @@ __all__ = [
     'ColumnPinningState',
     'CreateSavedViewRequest',
     'CreateSavedViewResponse',
+    'CustomTimeRange',
     'DisplayState',
     'DisplayStateVisitor',
     'GetSavedViewResponse',
