@@ -10,6 +10,7 @@ from .._impl import (
     scout_workbookcommon_api_TagString as TagString,
     scout_workbookcommon_api_TagStringLiteral as TagStringLiteral,
     scout_workbookcommon_api_TagStringVisitor as TagStringVisitor,
+    scout_workbookcommon_api_TimeRange as TimeRange,
     scout_workbookcommon_api_UnifiedWorkbookContent as UnifiedWorkbookContent,
     scout_workbookcommon_api_UnifiedWorkbookContentVisitor as UnifiedWorkbookContentVisitor,
     scout_workbookcommon_api_WorkbookContent as WorkbookContent,
@@ -18,6 +19,10 @@ from .._impl import (
     scout_workbookcommon_api_WorkbookInputsV1 as WorkbookInputsV1,
     scout_workbookcommon_api_WorkbookInputsVisitor as WorkbookInputsVisitor,
     scout_workbookcommon_api_WorkbookSettings as WorkbookSettings,
+    scout_workbookcommon_api_WorkbookTimeRangeType as WorkbookTimeRangeType,
+    scout_workbookcommon_api_WorkbookTimeSettings as WorkbookTimeSettings,
+    scout_workbookcommon_api_WorkbookTimeSettingsV1 as WorkbookTimeSettingsV1,
+    scout_workbookcommon_api_WorkbookTimeSettingsVisitor as WorkbookTimeSettingsVisitor,
 )
 
 __all__ = [
@@ -31,6 +36,7 @@ __all__ = [
     'TagString',
     'TagStringVisitor',
     'TagStringLiteral',
+    'TimeRange',
     'UnifiedWorkbookContent',
     'UnifiedWorkbookContentVisitor',
     'WorkbookContent',
@@ -39,5 +45,9 @@ __all__ = [
     'WorkbookInputsVisitor',
     'WorkbookInputsV1',
     'WorkbookSettings',
+    'WorkbookTimeRangeType',
+    'WorkbookTimeSettings',
+    'WorkbookTimeSettingsVisitor',
+    'WorkbookTimeSettingsV1',
 ]
 
